__author__ = 'Jabrail Lezgintsev'
__credits__ = ['Jabrail Lezgintsev']
__license__ = 'MIT'
__version__ = '0.3.0'
__maintainer__ = 'Jabrail Lezgintsev'
__email__ = 'lezgintsev13@yandex.ru'
__status__ = 'Beta'
